<?php
namespace FM\Factory;

use Doctrine\ORM\EntityManager;

class ListagemVistoriasFactory
{

    protected $connection;

    public function __construct(EntityManager $entityManager) {

        $this->connection = $entityManager->getConnection();
    }

    // Funções da Tela de Listagem de Vistorias
    public function getPlaceSurvey() {

        $sql = "SELECT DISTINCT LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTE
                  FROM FCM_LOCALCLI LC
                  JOIN FCM_GERENCIAMENTOCHK GCHK
                  ON LC.NRLOCALCLIENTE = GCHK.NRLOCALCLIENTE";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    public function getEmployee($usersIds) {

        $sql = "SELECT DISTINCT FUNC.NMFUNCIONARIO, FUNC.NRFUNCIONARIO
                  FROM FCM_FUNCIONARIO FUNC
                  JOIN FCM_GERENCIAMENTOCHK GCHK
                  ON FUNC.NRFUNCIONARIO = GCHK.NRFUNCIONARIO
                 WHERE FUNC.NRFUNCIONARIO IN ({$usersIds})";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    public function getSituation() {

        $sql = "SELECT DISTINCT FCM_GERENCIAMENTOCHK.IDSITUACAOGERCHK AS NRIDSITUACAOAGEND,
                CASE FCM_GERENCIAMENTOCHK.IDSITUACAOGERCHK WHEN '1' THEN 'Aguardando vistoria'
                   WHEN '2' THEN 'Em andamento'
                   WHEN '3' THEN 'Avaliado'
                   WHEN '4' THEN 'Cancelado'
                   ELSE NULL END AS IDSITUACAOGERCHK
                   FROM FCM_GERENCIAMENTOCHK";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();
    }

    public function cardsSurveys($parametro, $usersIds) {

        $sql = "SELECT GCHK.NRGERENCIAMENTOCHK, GCHK.NMGERENCIAMENTOCHK, GCHK.NRLOCALCLIENTE, GCHK.NRFUNCIONARIO, GCHK.IDSITUACAOGERCHK,
                  TO_CHAR(GCHK.DTHORAAGEND, 'DD/MM HH24:MI')DTHORAAGEND, FUNC.NMFUNCIONARIO, LC.NMLOCALCLIENTE, LC.NRLOCALCLIENTEPAI AS LOCALPAI, LCP.NMLOCALCLIENTE AS NMLOCALPAI, CA.IDSITUACAOAGEND,
                      DECODE(CA.IDSITUACAOAGEND, '4', CASE GCHK.IDSITUACAOGERCHK WHEN '1' THEN 'Aguardando Vistoria'
                                        WHEN '2' THEN 'Em andamento'
                                        WHEN '3' THEN 'Avaliado'
                                        ELSE NULL END, DECODE(GCHK.IDSITUACAOGERCHK, '4', 'Cancelado', 'Tarefa Pendente')) AS IDSITUACAOGERCHK
                          FROM FCM_GERENCIAMENTOCHK GCHK
                          INNER JOIN FCM_LOCALCLI LC
                          ON LC.NRLOCALCLIENTE = GCHK.NRLOCALCLIENTE
                          INNER JOIN FCM_FUNCIONARIO FUNC
                          ON FUNC.NRFUNCIONARIO = GCHK.NRFUNCIONARIO
                          INNER JOIN FCM_LOCALCLI LCP
                          ON LCP.NRLOCALCLIENTE = LC.NRLOCALCLIENTEPAI
                          INNER JOIN FCM_CHECKLISTAGEND CA
                          ON CA.NRCHECKLISTAGEND = GCHK.NRCHECKLISTAGEND".$parametro."
                          AND GCHK.NRFUNCIONARIO IN ({$usersIds})
                          ORDER BY DTHORAAGEND";

        $std = $this->connection->prepare($sql);

        $std->execute();
        return $std->fetchAll();

    }

    // Funções da tela de Detlahes da Vistoria

    // Select para trazer as atividades
    public function getActivities($parametros) {

        $sql = "SELECT DISTINCT FCM_ATIVIDADECHK.NRATIVIDADECHK, FCM_ATIVIDADE.NMATIVIDADE
                  FROM FCM_ATIVIDADECHK
                  JOIN FCM_ATIVIDADE
                    ON FCM_ATIVIDADE.NRATIVIDADE = FCM_ATIVIDADECHK.NRATIVIDADE
                  JOIN FCM_TAREFACHK
                    ON FCM_TAREFACHK.NRATIVIDADECHK = FCM_ATIVIDADECHK.NRATIVIDADECHK
                    AND NRTAREFACHK IN (SELECT NRTAREFACHK
                                          FROM FCM_TAREFAGERCHK
                                         WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK)";

        $std = $this->connection->prepare($sql);

        $std->execute($parametros);
        return $std->fetchAll();
    }

    // Select para trazer a tarefa (Onde estarão as observações)
    // Caso esse select traga mais de uma observação, pode concatenar as observações,
    // colcoando duas quebras de linha entre elas)
    public function getTask($parametros) {

        $sql = "SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK, FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK, FCM_TAREFAGERCHK.DSOBSTAREFAGERCHK, FCM_GERENCIAMENTOCHK.IDSITUACAOGERCHK, FCM_CHECKLISTAGEND.IDSITUACAOAGEND
                  FROM FCM_TAREFAGERCHK
                  JOIN FCM_TAREFACHK
                  ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                  JOIN FCM_GERENCIAMENTOCHK
                  ON FCM_GERENCIAMENTOCHK.NRGERENCIAMENTOCHK = FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK
                  JOIN FCM_CHECKLISTAGEND
                  ON FCM_CHECKLISTAGEND.NRCHECKLISTAGEND = FCM_GERENCIAMENTOCHK.NRCHECKLISTAGEND
                  WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                  AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK";

        $std = $this->connection->prepare($sql);

        $std->execute($parametros);
        return $std->fetchAll();
    }

    // Select para trazer os critérios
    public function getCriteria($parametros) {

        $sql = "SELECT NRCRITERIOTARGERCHK, NMCRITERIOTARGERCHK, IDMARCADO
                  FROM FCM_CRITERIOTARGERCHK
                 WHERE NRTAREFAGERCHK = :NRTAREFAGERCHK";

        $std = $this->connection->prepare($sql);

        $std->execute($parametros);
        return $std->fetchAll();
    }

    public function upCriterias($parametros, $paramQuery) {
      
        $sql = "UPDATE FCM_CRITERIOTARGERCHK
                  SET IDMARCADO = :IDMARCADO,
                    DTULTATU = SYSDATE
                  WHERE NRCRITERIOTARGERCHK IN (SELECT NRCRITERIOTARGERCHK
                                                    FROM FCM_CRITERIOTARGERCHK
                                                   WHERE NRTAREFAGERCHK IN (SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK
                                                    FROM FCM_TAREFAGERCHK
                                                    JOIN FCM_TAREFACHK
                                                      ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                                                   WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                                                     AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK))".$paramQuery;
        // debugApi([$paramQuery]);
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function upObservation($parametros) {

        $sql = "UPDATE FCM_TAREFAGERCHK
                SET DSOBSTAREFAGERCHK = :DSOBSTAREFAGERCHK
                    WHERE NRTAREFAGERCHK IN (SELECT FCM_TAREFAGERCHK.NRTAREFAGERCHK
                                  FROM FCM_TAREFAGERCHK
                                  JOIN FCM_TAREFACHK
                                    ON FCM_TAREFACHK.NRTAREFACHK = FCM_TAREFAGERCHK.NRTAREFACHK
                                 WHERE FCM_TAREFAGERCHK.NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK
                                   AND FCM_TAREFACHK.NRATIVIDADECHK = :NRATIVIDADECHK)";
        // debugApi([$paramQuery]);
        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }

    public function upStatusSurvey($parametros) {
       // debugApi([$parametros]);
        $sql = "UPDATE FCM_GERENCIAMENTOCHK
                SET IDSITUACAOGERCHK = :IDSITUACAOGERCHK,
                DTULTATU = SYSDATE
                  WHERE NRGERENCIAMENTOCHK = :NRGERENCIAMENTOCHK";


        $std = $this->connection->prepare($sql);
        $std->execute($parametros);
    }
}