/* Tabela ENDECLIE: Endereo do Cliente */
/* Descrio: A trigger insere registros na tabela ALTERAPARTSPED a partir de alteraes
na tabela ENDECLIE */
/* Objetivo: Registrar as alteraes realizadas nos campos CDPAIS, CDMUNICIPIO, DSENDECLIE, DSCOMPENDCLI, CDBAIRRO 
da tabela ENDECLIE, para serem utilizadas na gerao do registro 0175 do Sped Fiscal */

create or replace
TRIGGER ALTERA_END_CLIE_SPED
AFTER UPDATE
ON ENDECLIE FOR EACH ROW
DECLARE  
  V_NRSEQALTPARTSPED NUMBER;
  V_DTOPER           DATE;
  V_CDMUNICIBGE      VARCHAR2(10);
  V_CDPAISBACEN      VARCHAR2(10);
BEGIN
  IF UPDATING THEN 
    IF (((:OLD.CDPAIS <> :NEW.CDPAIS) OR (:NEW.CDPAIS IS NULL)) AND (:OLD.CDPAIS IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;
        
       BEGIN
            SELECT CDPAISBACEN
              INTO V_CDPAISBACEN
              FROM PAIS
             WHERE CDPAIS = :OLD.CDPAIS;
       EXCEPTION 
            WHEN NO_DATA_FOUND THEN
                 V_CDPAISBACEN := NULL;
       END;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'C'||:OLD.CDCLIENTE
               AND CDCAMPO = '04'
               AND DTALTERACAO < V_DTOPER;
       END;
        
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'C'||:OLD.CDCLIENTE,'04',V_DTOPER,V_CDPAISBACEN);
    END IF;
    
    IF (((:OLD.CDMUNICIPIO <> :NEW.CDMUNICIPIO) OR (:NEW.CDMUNICIPIO IS NULL)) AND (:OLD.CDMUNICIPIO IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0;
       END;
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            SELECT CDMUNICIBGE
              INTO V_CDMUNICIBGE
              FROM MUNICIPIO
             WHERE CDMUNICIPIO = :OLD.CDMUNICIPIO
               AND CDPAIS      = :OLD.CDPAIS
               AND SGESTADO    = :OLD.SGESTADO;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_CDMUNICIBGE := NULL;
       END;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'C'||:OLD.CDCLIENTE
               AND CDCAMPO = '08'
               AND DTALTERACAO < V_DTOPER;
       END;

       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT)
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'C'||:OLD.CDCLIENTE,'08',V_DTOPER,V_CDMUNICIBGE);
    END IF;

    IF (((:OLD.DSENDECLIE <> :NEW.DSENDECLIE) OR (:NEW.DSENDECLIE IS NULL)) AND (:OLD.DSENDECLIE IS NOT NULL))THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'C'||:OLD.CDCLIENTE
               AND CDCAMPO = '10'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'C'||:OLD.CDCLIENTE,'10',V_DTOPER,:OLD.DSENDECLIE);    
    END IF;
    
    IF (((:OLD.DSCOMPENDCLI <> :NEW.DSCOMPENDCLI) OR (:NEW.DSCOMPENDCLI IS NULL)) AND (:OLD.DSCOMPENDCLI IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'C'||:OLD.CDCLIENTE
               AND CDCAMPO = '12'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'C'||:OLD.CDCLIENTE,'12',V_DTOPER,:OLD.DSCOMPENDCLI);    
    END IF;

    IF (((:OLD.CDBAIRRO <> :NEW.CDBAIRRO) OR (:NEW.CDBAIRRO IS NULL)) AND (:OLD.CDBAIRRO IS NOT NULL)) THEN
       BEGIN
            SELECT MAX(NRSEQALTPARTSPED)
              INTO V_NRSEQALTPARTSPED
              FROM ALTERAPARTSPED;
       EXCEPTION
            WHEN NO_DATA_FOUND THEN
                 V_NRSEQALTPARTSPED := 0; 
       END;
       V_NRSEQALTPARTSPED := NVL(V_NRSEQALTPARTSPED,0)+1;
       V_DTOPER := SYSDATE;

       BEGIN
            DELETE ALTERAPARTSPED
             WHERE CDCHAVE = 'C'||:OLD.CDCLIENTE
               AND CDCAMPO = '13'
               AND DTALTERACAO < V_DTOPER;
       END;
       
       INSERT INTO ALTERAPARTSPED (NRSEQALTPARTSPED,CDCHAVE,CDCAMPO,DTALTERACAO,DSCONTEUDOANT) 
            VALUES (LPAD(V_NRSEQALTPARTSPED,'10','0'),'C'||:OLD.CDCLIENTE,'13',V_DTOPER,:OLD.CDBAIRRO);    
    END IF;
  END IF;
END;
/
-- VERSAO --
BEGIN ATUVEROBJ('ALTERA_END_CLIE_SPED','5.85.000'); END;
/